# isEven

Uma biblioteca simples para verificar se um número é par.

## Instalação
```bash
pip install isEven-Easy
```

## Uso
```python
from isEven import isEven

print(isEven(4))   # True
print(isEven(7))   # False
```